터틀 프로그램에 대한 특별한 지원에 대해
===================================

``turtle``모듈로 프로그램을 개발할 때, turcar는 다음의 내용을 지원합니다:

* 스크립트에서 ``mainloop``, ``done`` 혹은 ``exitonclick`` 호출을 생략 할 수 있습니다 (turcar는 Turtle 창은 반응형으로 유지). 스크립트로 드로잉의 일부를 만들고 셸을 통해 지속적으로 피쳐를 추가 할 수 있습니다. 셸을 통해 전체 드로잉을 생성 할 수도 있습니다.
* `Turtle 윈도우 <dock.rst>_도킹`을 통해 스크립트 작업하는 동시에 확인 할 수 있습니다.
